==> ejc-signaturemanage-api-3.0.1-20211210.013705-43-sources.jar: com.ejianc.business.signaturemanage/vo/SealInfoVO.java <==
package com.ejianc.business.signaturemanage.vo;

import java.util.ArrayList;
import java.util.List;

/**
 * @author baipengyan
 * @description: 印章详情VO
 * @date 2021/12/2 11:13
 */
public class SealInfoVO {
    private static final long serialVersionUID = 1L;

    List<SignatoryVO> signatoryVOList = new ArrayList<>(); // 签章人信息
    // @NotEmpty(message = "平台印章id不能为空！")
    private java.lang.String sealId; // 平台印章id
    // @NotEmpty(message = "平台印章name不能为空！")
    private java.lang.String sealName; // 平台印章name
    // @NotEmpty(message = "印章使用平台用户id范围不能为空！")
    private java.lang.String signatureUserIds; // 印章使用平台用户id范围（静态）多个逗号分隔
    // @NotEmpty(message = "不能为空！")
    private java.lang.String sourceSealId; // 印章id第三方系统返回的）
    // @NotEmpty(message = "不能为空！")
    private java.lang.String sourceSealName; // 印章name（第三方系统返回的）
    // @NotEmpty(message = "签署动作类型不能为空！")
    private java.lang.String signActionType; // 签署动作类型:CORPORATE（企业签 章），PERSONAL（个人签字），LP（法 定代表人签字）
    // @NotEmpty(message = "签署动作编号不能为空！")
    private java.lang.String actionNo; // 签署动作编号，唯一
    // @NotEmpty(message = "签署动作名称不能为空！")
    private java.lang.String name; // 签署动作名称,根据签署动作类型填写
    // @NotNull(message = "签章顺序不能为空！")
    private java.lang.Integer sealSignOrder; // 签章顺序,前置设置1，后置逐渐增大，无序设置相同

    public String getSealId() {
        return sealId;
    }

    public void setSealId(String sealId) {
        this.sealId = sealId;
    }

    public String getSealName() {
        return sealName;
    }

    public void setSealName(String sealName) {
        this.sealName = sealName;
    }

    public String getSignatureUserIds() {
        return signatureUserIds;
    }

    public void setSignatureUserIds(String signatureUserIds) {
        this.signatureUserIds = signatureUserIds;
    }

    public String getSourceSealId() {
        return sourceSealId;
    }

    public void setSourceSealId(String sourceSealId) {
        this.sourceSealId = sourceSealId;
    }

    public String getSourceSealName() {
        return sourceSealName;
    }

    public void setSourceSealName(String sourceSealName) {
        this.sourceSealName = sourceSealName;
    }

    public String getSignActionType() {
        return signActionType;
    }

    public void setSignActionType(String signActionType) {
        this.signActionType = signActionType;
    }

    public String getActionNo() {
        return actionNo;
    }

    public void setActionNo(String actionNo) {
        this.actionNo = actionNo;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getSealSignOrder() {
        return sealSignOrder;
    }

    public void setSealSignOrder(Integer sealSignOrder) {
        this.sealSignOrder = sealSignOrder;
    }

    public List<SignatoryVO> getSignatoryVOList() {
        return signatoryVOList;
    }

    public void setSignatoryVOList(List<SignatoryVO> signatoryVOList) {
        this.signatoryVOList = signatoryVOList;
    }
}

==> ejc-signaturemanage-api-3.0.1-20220520.083456-156-sources.jar: com.ejianc.business.signaturemanage/vo/SealInfoVO.java <==
package com.ejianc.business.signaturemanage.vo;

import java.util.ArrayList;
import java.util.List;

/**
 * @author baipengyan
 * @description: 印章详情VO-签署动作/签署节点
 * @date 2021/12/2 11:13
 */
public class SealInfoVO {
    private static final long serialVersionUID = 1L;

    List<SignatoryVO> signatoryVOList = new ArrayList<>(); // 签章人信息
    List<SignatoryRectVO> signatoryRectVOList = new ArrayList<>(); // 签署位置
    // @NotEmpty(message = "平台印章id不能为空！")
    private java.lang.String sealId; // 平台印章id
    // @NotEmpty(message = "平台印章name不能为空！")
    private java.lang.String sealName; // 平台印章name
    // @NotEmpty(message = "印章使用平台用户id范围不能为空！")
    private java.lang.String signatureUserIds; // 印章使用平台用户id范围（静态）多个逗号分隔
    // @NotEmpty(message = "不能为空！")
    private java.lang.String sourceSealId; // 印章id第三方系统返回的）
    // @NotEmpty(message = "不能为空！")
    private java.lang.String sourceSealName; // 印章name（第三方系统返回的）
    // @NotEmpty(message = "签署动作类型不能为空！")
    private java.lang.String signActionType; // 签署动作类型:CORPORATE（企业签 章），PERSONAL（个人签字），LP（法 定代表人签字）
    // @NotEmpty(message = "签署动作编号不能为空！")
    private java.lang.String actionNo; // 签署动作编号，唯一
    // @NotEmpty(message = "签署动作名称不能为空！")
    private java.lang.String name; // 签署动作名称,根据签署动作类型填写
    // @NotNull(message = "签章顺序不能为空！")
    private java.lang.Integer sealSignOrder; // 签章顺序,前置设置1，后置逐渐增大，无序设置相同

    public String getSealId() {
        return sealId;
    }

    public void setSealId(String sealId) {
        this.sealId = sealId;
    }

    public String getSealName() {
        return sealName;
    }

    public void setSealName(String sealName) {
        this.sealName = sealName;
    }

    public String getSignatureUserIds() {
        return signatureUserIds;
    }

    public void setSignatureUserIds(String signatureUserIds) {
        this.signatureUserIds = signatureUserIds;
    }

    public String getSourceSealId() {
        return sourceSealId;
    }

    public void setSourceSealId(String sourceSealId) {
        this.sourceSealId = sourceSealId;
    }

    public String getSourceSealName() {
        return sourceSealName;
    }

    public void setSourceSealName(String sourceSealName) {
        this.sourceSealName = sourceSealName;
    }

    public String getSignActionType() {
        return signActionType;
    }

    public void setSignActionType(String signActionType) {
        this.signActionType = signActionType;
    }

    public String getActionNo() {
        return actionNo;
    }

    public void setActionNo(String actionNo) {
        this.actionNo = actionNo;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getSealSignOrder() {
        return sealSignOrder;
    }

    public void setSealSignOrder(Integer sealSignOrder) {
        this.sealSignOrder = sealSignOrder;
    }

    public List<SignatoryVO> getSignatoryVOList() {
        return signatoryVOList;
    }

    public void setSignatoryVOList(List<SignatoryVO> signatoryVOList) {
        this.signatoryVOList = signatoryVOList;
    }

    public List<SignatoryRectVO> getSignatoryRectVOList() {
        return signatoryRectVOList;
    }

    public void setSignatoryRectVOList(List<SignatoryRectVO> signatoryRectVOList) {
        this.signatoryRectVOList = signatoryRectVOList;
    }
}
